#!/bin/bash
#plot_profile.sh

raise()
{
  echo "${1}" >&2
}

check_tools() {
	raise "
   Checking for required libraries and components on this system
   "
	 deeptools --version &> version_deeptools.txt
	 if [ $? -gt 0 ]
	 	then
			raise "Missing deeptools"
			return 1
		fi
}

compute_matrix() {
  raise "
  Computing matrix on ${1} using ${2}
  "

	computeMatrix reference-point \
		--referencePoint TSS \
		-S ${1} \
		-R ${2} \
		--skipZeros \
		-o computeMatrix.gz \
		-p max/2

  if [ $? -gt 0 ]
  then
    raise "Problem building matrix"
    return 1
  fi
}

plot_profile() {
  raise "
  Plotting profile
  "

	plotProfile -m computeMatrix.gz \
		-out plotProfile.png

  if [ $? -gt 0 ]
  then
    raise "Problem plotting"
    return 1
  fi
}


run_main() {
	bws=$(ls *.bw)
	gtf=$(ls *.gtf *.bed)

  check_tools || exit 1

	compute_matrix "${bws}" "${gtf}" || return 1

	plot_profile || return 1

  raise "ALL COMPLETE"
}

if [[ "${BASH_SOURCE[0]}" == "${0}" ]]
then
  run_main
  if [ $? -gt 0 ]
  then
    exit 1
  fi
fi
